import os
import sys
sys.path.append("./deps")

from pspring import *
from pspringaws import *

@LambdaHandler()
class TestLambdaHandler():
    def handler(self,event,context):
        raise RedirectException()

handler = TestLambdaHandler().handler

print(handler({},{}))



import os
region = os.environ.get("pspring.aws.region","us-east-2") or os.environ.get("region","us-east-2")
defaultTtl = os.environ.get("pspring.aws.dynamodb.ttl","3600")
secretName = os.environ.get("pspring.aws.secretsMngr.secretName")

import logging
logger = logging.getLogger("pspring-aws")



from .defaultvars import *
from .lambdaexceptions import *
import json

class LambdaHandler():

    def __init__(self,*args,**kargs):
        self.type = kargs.get("type","proxy")

    def __call__(self,classObj):
        handlerOrig = classObj.handler
        def handler(*args,**kargs):
            try:
                response = handlerOrig(*args,**kargs)
                return {
                    "statusCode" : "200",
                    "body" : json.dumps(response)
                }
            except LambdaException as le:
                return le.getResponse()
            except Exception as e:
                return LambdaException(msg=str(e)).getResponse()

        classObj.handler = handler
        return classObj



import boto3

from .defaultvars import *

dynamodb = boto3.resource("dynamodb")

class DynamoDBTable():
    def __init__(self,*args,**kargs):
        self.tableName = kargs.get("tableName")
        self.primaryKey = kargs.get("primaryKey")
        self.sortKey = kargs.get("sortKey")
        self.ttl = int(kargs.get("ttl",defaultTtl))
        self.table = dynamodb.table(sel.tableName,region_name=region)

    def __call__(self,classObj):
        def put(self,data):
            self.table.put_item(Item=data)

        def get(self,primaryKey,**kargs):
            key = {
                self.primaryKey : primaryKey
            }
            sortKey = kargs.get(self.sortKey,None)
            columns = kargs.get("columns",[])
            if self.sortKey != None and sortKey != None:
                key.update({
                    self.sortKey : sortKey
                })

            response = self.table.get_item(Key=key)
            responseData = {}
            item = response.get("Item")
            if item != None:
                for column in columns:
                    responseData.update({
                        column : item.get("column")
                    })
                return responseData
            return None



import json

class LambdaException(Exception):
    def __init__(self,**kargs):
        super().__init__(**kargs)
        self.code = kargs.get("code","500")
        self.msg = kargs.get("msg","Internal Server Error : "+str(self))
        self.errorCode = kargs.get("errorCode")

    def getResponse(self):
        return {
            "statusCode": self.code,
            "body": json.dumps({
                "message" : self.msg,
                "code" : self.errorCode
            })
        }

class NotFoundException(LambdaException):
    def __init__(self,**kargs):
        super().__init__(**kargs)
        self.code="404"

class UnAuthorizedException(LambdaException):
    def __init__(self,**kargs):
        super().__init__(**kargs)
        self.code="401"

class InternalServerException(LambdaException):
    def __init__(self,**kargs):
        super().__init__(**kargs)
        self.code="500"

class CreatedException(LambdaException):
    def __init__(self,**kargs):
        super().__init__(**kargs)
        self.code="201"

class RedirectException(LambdaException):
    def __init__(self,**kargs):
        super().__init__(**kargs)
        self.code="301"
